% ======================================================
% Function for the example "Optimal Transmission Design"
% ======================================================



% #####################################################################################################################

function V_result = OptiGear(x);

% #####################################################################################################################

% Global variables
% ----------------

    % Simulation
    global t
    global N_sim    
    global w_CE T_CE
    global gear_result 
    global V_liter 
    global first_gear second_gear third_gear fourth_gear fifth_gear
    
    % Combustion Engine map
    global eta_CE_map
    global w_CE_row
    global T_CE_col
    global w_CE_max
    global T_CE_max    
   
% Set actual gear ratios
% ----------------------
    first_gear      = x(1);
    second_gear     = x(2);
    third_gear      = x(3);
    fourth_gear     = x(4);
    fifth_gear      = x(5);

% Build matrix of gear ratio values
% ---------------------------------
    gear_result = [gear_result; x'];
            
% Do simulation    
% -------------
    sim('qss_example_optigear');
            
% Consider last value of the computed fuel consumption vector
% -----------------------------------------------------------
    V_result = V_liter(max(size(t)));
        
% Check whether cycle could be finished exactly in N_sim computational steps;
% if cycle duration is less than N_sim, set fuel consumption to infinite
% ---------------------------------------------------------------------------
    if (max(size(t)) < N_sim)
    	V_result = Inf;
    end
        
% Plausibility check of the computed gear ratios
% ----------------------------------------------
    if (first_gear > second_gear) && (second_gear > third_gear) && (third_gear > fourth_gear) && (fourth_gear > fifth_gear)
        V_result = V_result;
    else
        V_result = Inf;
    end
    
% Display actual fuel consumption
% -------------------------------
    disp(['V [liter/100 km] =       ',num2str(V_result)]);
    
% #####################################################################################################################

